<?php
	/**
	* SQL Generator for SAPDB
	* @author Kai Hofmann &lt;khofmann@probusiness.de&gt;
	* @copyright Copyright (C) 2003,2004 Free Software Foundation, Inc.
	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
	* @package phpgwapi
	* @subpackage database
	* @version $Id: class.sql_sapdb.inc.php 1040 2008-05-26 10:27:54Z dave $
	*/

	/**
	* SQL Generator for SAPDB
	*
	* @package phpgwapi
	* @subpackage database
	* @ignore
	*/
	class phpgwapi_sql extends phpgwapi_sql_
	{
		public static function sql_()
		{
		}
	}
